﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/bcm-pricing-calculator/model/BatchCreateWorkloadEstimateUsageError.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::Utils::Json;
using namespace Aws::Utils;

namespace Aws
{
namespace BCMPricingCalculator
{
namespace Model
{

BatchCreateWorkloadEstimateUsageError::BatchCreateWorkloadEstimateUsageError() : 
    m_keyHasBeenSet(false),
    m_errorCode(BatchCreateWorkloadEstimateUsageCode::NOT_SET),
    m_errorCodeHasBeenSet(false),
    m_errorMessageHasBeenSet(false)
{
}

BatchCreateWorkloadEstimateUsageError::BatchCreateWorkloadEstimateUsageError(JsonView jsonValue)
  : BatchCreateWorkloadEstimateUsageError()
{
  *this = jsonValue;
}

BatchCreateWorkloadEstimateUsageError& BatchCreateWorkloadEstimateUsageError::operator =(JsonView jsonValue)
{
  if(jsonValue.ValueExists("key"))
  {
    m_key = jsonValue.GetString("key");

    m_keyHasBeenSet = true;
  }

  if(jsonValue.ValueExists("errorCode"))
  {
    m_errorCode = BatchCreateWorkloadEstimateUsageCodeMapper::GetBatchCreateWorkloadEstimateUsageCodeForName(jsonValue.GetString("errorCode"));

    m_errorCodeHasBeenSet = true;
  }

  if(jsonValue.ValueExists("errorMessage"))
  {
    m_errorMessage = jsonValue.GetString("errorMessage");

    m_errorMessageHasBeenSet = true;
  }

  return *this;
}

JsonValue BatchCreateWorkloadEstimateUsageError::Jsonize() const
{
  JsonValue payload;

  if(m_keyHasBeenSet)
  {
   payload.WithString("key", m_key);

  }

  if(m_errorCodeHasBeenSet)
  {
   payload.WithString("errorCode", BatchCreateWorkloadEstimateUsageCodeMapper::GetNameForBatchCreateWorkloadEstimateUsageCode(m_errorCode));
  }

  if(m_errorMessageHasBeenSet)
  {
   payload.WithString("errorMessage", m_errorMessage);

  }

  return payload;
}

} // namespace Model
} // namespace BCMPricingCalculator
} // namespace Aws
