﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/bedrock/model/GenerationConfiguration.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::Utils::Json;
using namespace Aws::Utils;

namespace Aws
{
namespace Bedrock
{
namespace Model
{

GenerationConfiguration::GenerationConfiguration() : 
    m_promptTemplateHasBeenSet(false),
    m_guardrailConfigurationHasBeenSet(false),
    m_kbInferenceConfigHasBeenSet(false),
    m_additionalModelRequestFieldsHasBeenSet(false)
{
}

GenerationConfiguration::GenerationConfiguration(JsonView jsonValue)
  : GenerationConfiguration()
{
  *this = jsonValue;
}

GenerationConfiguration& GenerationConfiguration::operator =(JsonView jsonValue)
{
  if(jsonValue.ValueExists("promptTemplate"))
  {
    m_promptTemplate = jsonValue.GetObject("promptTemplate");

    m_promptTemplateHasBeenSet = true;
  }

  if(jsonValue.ValueExists("guardrailConfiguration"))
  {
    m_guardrailConfiguration = jsonValue.GetObject("guardrailConfiguration");

    m_guardrailConfigurationHasBeenSet = true;
  }

  if(jsonValue.ValueExists("kbInferenceConfig"))
  {
    m_kbInferenceConfig = jsonValue.GetObject("kbInferenceConfig");

    m_kbInferenceConfigHasBeenSet = true;
  }

  if(jsonValue.ValueExists("additionalModelRequestFields"))
  {
    Aws::Map<Aws::String, JsonView> additionalModelRequestFieldsJsonMap = jsonValue.GetObject("additionalModelRequestFields").GetAllObjects();
    for(auto& additionalModelRequestFieldsItem : additionalModelRequestFieldsJsonMap)
    {
      m_additionalModelRequestFields[additionalModelRequestFieldsItem.first] = additionalModelRequestFieldsItem.second.AsObject();
    }
    m_additionalModelRequestFieldsHasBeenSet = true;
  }

  return *this;
}

JsonValue GenerationConfiguration::Jsonize() const
{
  JsonValue payload;

  if(m_promptTemplateHasBeenSet)
  {
   payload.WithObject("promptTemplate", m_promptTemplate.Jsonize());

  }

  if(m_guardrailConfigurationHasBeenSet)
  {
   payload.WithObject("guardrailConfiguration", m_guardrailConfiguration.Jsonize());

  }

  if(m_kbInferenceConfigHasBeenSet)
  {
   payload.WithObject("kbInferenceConfig", m_kbInferenceConfig.Jsonize());

  }

  if(m_additionalModelRequestFieldsHasBeenSet)
  {
   JsonValue additionalModelRequestFieldsJsonMap;
   for(auto& additionalModelRequestFieldsItem : m_additionalModelRequestFields)
   {
     additionalModelRequestFieldsJsonMap.WithObject(additionalModelRequestFieldsItem.first, additionalModelRequestFieldsItem.second.View());
   }
   payload.WithObject("additionalModelRequestFields", std::move(additionalModelRequestFieldsJsonMap));

  }

  return payload;
}

} // namespace Model
} // namespace Bedrock
} // namespace Aws
